"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from ..... import neptune_pb
import typing
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RequestId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str

    def __init__(self, *, value: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['value', b'value']) -> None:
        ...
global___RequestId = RequestId

@typing.final
class RequestIdList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IDS_FIELD_NUMBER: builtins.int

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        ...

    def __init__(self, *, ids: collections.abc.Iterable[global___RequestId] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['ids', b'ids']) -> None:
        ...
global___RequestIdList = RequestIdList

@typing.final
class BulkRequestStatus(google.protobuf.message.Message):
    """Maps a list of request identifiers to their respective statuses.
    The backend API guarantees that the number of returned fields is equal
    to the number of requested IDs, and the order is the same as requested.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUSES_FIELD_NUMBER: builtins.int

    @property
    def statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[neptune_pb.ingest.v1.pub.request_status_pb2.RequestStatus]:
        ...

    def __init__(self, *, statuses: collections.abc.Iterable[neptune_pb.ingest.v1.pub.request_status_pb2.RequestStatus] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['statuses', b'statuses']) -> None:
        ...
global___BulkRequestStatus = BulkRequestStatus

@typing.final
class SubmitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUEST_ID_FIELD_NUMBER: builtins.int
    REQUEST_IDS_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    'wire-compatibility with RequestId. Will be deprecated'

    @property
    def request_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        ...

    def __init__(self, *, request_id: builtins.str=..., request_ids: collections.abc.Iterable[builtins.str] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['request_id', b'request_id', 'request_ids', b'request_ids']) -> None:
        ...
global___SubmitResponse = SubmitResponse

@typing.final
class StatusCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    project: builtins.str

    @property
    def request_id(self) -> global___RequestId:
        ...

    def __init__(self, *, project: builtins.str=..., request_id: global___RequestId | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['request_id', b'request_id']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['project', b'project', 'request_id', b'request_id']) -> None:
        ...
global___StatusCheck = StatusCheck

@typing.final
class BulkStatusCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    project: builtins.str

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        """wire-compatibility with RequestIdList"""

    def __init__(self, *, project: builtins.str=..., ids: collections.abc.Iterable[global___RequestId] | None=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['ids', b'ids', 'project', b'project']) -> None:
        ...
global___BulkStatusCheck = BulkStatusCheck

@typing.final
class BulkCheckDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    NEXT_CURSOR_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    project: builtins.str
    next_cursor: builtins.str
    limit: builtins.int

    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RequestId]:
        ...

    def __init__(self, *, project: builtins.str=..., ids: collections.abc.Iterable[global___RequestId] | None=..., next_cursor: builtins.str | None=..., limit: builtins.int | None=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['_limit', b'_limit', '_next_cursor', b'_next_cursor', 'limit', b'limit', 'next_cursor', b'next_cursor']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['_limit', b'_limit', '_next_cursor', b'_next_cursor', 'ids', b'ids', 'limit', b'limit', 'next_cursor', b'next_cursor', 'project', b'project']) -> None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_limit', b'_limit']) -> typing.Literal['limit'] | None:
        ...

    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal['_next_cursor', b'_next_cursor']) -> typing.Literal['next_cursor'] | None:
        ...
global___BulkCheckDetail = BulkCheckDetail

@typing.final
class IngestResultDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUEST_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    INGEST_CODE_FIELD_NUMBER: builtins.int
    ERROR_DETAIL_FIELD_NUMBER: builtins.int
    path: builtins.str
    ingest_code: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType
    error_detail: builtins.str

    @property
    def request_id(self) -> global___RequestId:
        ...

    def __init__(self, *, request_id: global___RequestId | None=..., path: builtins.str=..., ingest_code: neptune_pb.ingest.v1.ingest_pb2.IngestCode.ValueType=..., error_detail: builtins.str=...) -> None:
        ...

    def HasField(self, field_name: typing.Literal['request_id', b'request_id']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing.Literal['error_detail', b'error_detail', 'ingest_code', b'ingest_code', 'path', b'path', 'request_id', b'request_id']) -> None:
        ...
global___IngestResultDetail = IngestResultDetail

@typing.final
class BulkIngestResultDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DETAILS_FIELD_NUMBER: builtins.int
    NEXT_CURSOR_FIELD_NUMBER: builtins.int
    next_cursor: builtins.str

    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngestResultDetail]:
        ...

    def __init__(self, *, details: collections.abc.Iterable[global___IngestResultDetail] | None=..., next_cursor: builtins.str=...) -> None:
        ...

    def ClearField(self, field_name: typing.Literal['details', b'details', 'next_cursor', b'next_cursor']) -> None:
        ...
global___BulkIngestResultDetail = BulkIngestResultDetail